FermiLib plugin to interface with Psi4
======================================

This repository contains a plugin which allows `FermiLib <http://github.com/ProjectQ-Framework/FermiLib>`__ (licensed under Apache 2) to interface with the open-source quantum chemistry package `Psi4 <http://www.psicode.org>`__ (licensed under GNU Lesser General Public License version 3). 

Installation
------------

To install this plugin, clone this git repo and then change directory to the top level folder. Then, run

.. code-block:: bash

  python -m pip install -e .

Alternatively, one can install using pip with the command

.. code-block:: bash

  python -m pip install fermilibpluginpsi4

License
-------
Copyright (C) 2017 FermiLib Developers

This plugin is released under the GNU Lesser General Public License (LGPL), Version 3 or any later version.
